Used during bootstrap to initialize the cursor at the current position, preventing the first CDC poll from replaying the entire event history.
Used during bootstrap to initialize the cursor at the current position, preventing the first CDC poll from replaying the entire event history.